@@ -1,3 +1,7 @@
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdlib.h>
 #include <qvalidator.h>
 #include "adduserdlg.h"
@@ -13,9 +17,7 @@ AddUserDlg::AddUserDlg(ICQ *s, QWidget *parent = 0, const char *name = 0 ) : QDi
    edtUin->setGeometry(100, 15, 120, 20);
    edtUin->setValidator(new QIntValidator(0, 2147483647, edtUin));
    chkAlert = new QCheckBox("Alert User", this);
-   chkAlert->setStyle(WindowsStyle);
    chkAlert->setGeometry(10, 50, 80, 20);
-   chkAlert->setEnabled(false);  //for now
    btnOk = new QPushButton("Ok", this);
    btnOk->setGeometry(30, 80, 80, 30);
    btnCancel = new QPushButton("Cancel", this);
@@ -32,12 +34,19 @@ void AddUserDlg::show()
    QDialog::show();
 }
 
+void AddUserDlg::hide()
+{
+   QDialog::hide();
+   delete this;
+}
+
 
 void AddUserDlg::ok()
 {
-   server->addUser(atol((const char *)edtUin->text()), NULL, true);
+   unsigned long nUin = atol((const char *)edtUin->text());
+   server->usrAdd(nUin, NULL);
    if (chkAlert->isChecked()) // alert the user they were added
-   ;
-   emit updatedUsers();
+      server->icqAlertUser(nUin);
+   emit signal_updatedUsers();
    accept();
 }
