@@ -1,6 +1,10 @@
 #ifndef ADDUSER_H
 #define ADDUSER_H
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <qdialog.h>
 #include <qpushbt.h>
 #include <qlabel.h>
@@ -22,10 +26,11 @@ protected:
    QCheckBox *chkAlert;
 public slots:
    virtual void show();
+   virtual void hide();
 protected slots:
    void ok();
 signals:
-   void updatedUsers();
+   void signal_updatedUsers();
 };
 
 
