@@ -1,3 +1,7 @@
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdlib.h>
 #include <qvalidator.h>
 #include "authuserdlg.h"
@@ -28,8 +32,15 @@ void AuthUserDlg::show()
 }
 
 
+void AuthUserDlg::hide()
+{
+   QDialog::hide();
+   delete this;
+}
+
+
 void AuthUserDlg::ok()
 {
-   server->authorize(atol((const char *)edtUin->text()));
+   server->icqAuthorize(atol((const char *)edtUin->text()));
    accept();
 }
