@@ -1,6 +1,10 @@
 #ifndef AUTHUSER_H
 #define AUTHUSER_H
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <qdialog.h>
 #include <qpushbt.h>
 #include <qlabel.h>
@@ -20,6 +24,7 @@ protected:
    QLineEdit *edtUin;
 public slots:
    virtual void show();
+   virtual void hide();
 protected slots:
    void ok();
 };
