@@ -1,9 +1,16 @@
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <stdio.h>
 #include <qpushbt.h>
 #include "awaymsgdlg.h"
 
 
+int AwayMsgDlg::s_nX = 100;
+int AwayMsgDlg::s_nY = 100;
+
+
 AwayMsgDlg::AwayMsgDlg(ICQOwner *theOwner, QWidget *parent = 0, const char *name = 0) : QDialog(parent, name)
 {
    owner = theOwner;
@@ -23,12 +30,20 @@ AwayMsgDlg::AwayMsgDlg(ICQOwner *theOwner, QWidget *parent = 0, const char *name
 void AwayMsgDlg::show()
 {
    char title[128];
-   sprintf(title, "Set Away Message for %s:", owner->alias());
+   sprintf(title, "Set Away Message for %s:", owner->getAlias());
    setCaption(title);
-   mleAwayMsg->setText(owner->awayMessage());
+   mleAwayMsg->setText(owner->getAwayMessage());
+   setGeometry(s_nX, s_nY, width(), height());
    QDialog::show();
 }
 
+void AwayMsgDlg::hide()
+{
+  s_nX = x();
+  s_nY = y();
+  QDialog::hide();
+}
+
 
 void AwayMsgDlg::ok()
 {
