@@ -1,6 +1,10 @@
 #ifndef AWAYMSG_H
 #define AWAYMSG_H
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <qdialog.h>
 #include <qmlined.h>
 
@@ -13,9 +17,12 @@ class AwayMsgDlg : public QDialog
 public:
    AwayMsgDlg(ICQOwner *theOwner, QWidget *parent = 0, const char *name = 0);
    virtual void show();
+   virtual void hide();
 protected:
    ICQOwner *owner;
    MLEditWrap *mleAwayMsg;
+
+   static int s_nX, s_nY;
 protected slots:
    void ok();
 };
