@@ -1,10 +1,10 @@
+#ifndef KLICQ_H
+#define KLICQ_H
+ 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#ifndef KLICQ_H
-#define KLICQ_H
- 
 #include "icq.h"
 #include "licqgui.h"
 #include <kapp.h>
@@ -19,7 +19,7 @@ class KLicq : public QLabel
 	Q_OBJECT
 
 public:
-	KLicq(QWidget *parent=0);
+	KLicq(bool isDocked);
 	~KLicq();
 	
 	void reset();
@@ -29,9 +29,10 @@ signals:
 	void quitapp();
 	void lowericq();
 	void raiseicq();
+        void doubleClicked();
 
 public slots:
-        void change_dock_status(unsigned short int stat);
+        void change_dock_icon(const QPixmap *icon);
         void m_dock();
 
 protected slots:	
@@ -40,12 +41,12 @@ protected slots:
 protected:
 	void m_popupMenu(int x,int y);
         void mousePressEvent(QMouseEvent *);
-	QPixmap *pmOnline, *pmOffline, *pmAway, *pmDnd, *pmOccupied, *pmNa, *pmMessage;         
-	
+        void mouseDoubleClickEvent(QMouseEvent *);
+    
 private:
 	void m_displayPixmap();
 	bool m_isDocked;
-	unsigned short int OwnerStatus;
+	const QPixmap* OwnerIcon;
 };
 
 #endif
