@@ -1,22 +1,21 @@
 #ifndef LICQ_H
 #define LICQ_H
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <qapp.h>
 
 #include "icq.h"
 #include "licqgui.h"
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #ifdef USE_KDE
-#include "kicq.h"
+#include "klicq.h"
 class Licq : public KApplication
 #else
 class Licq : public QApplication
 #endif
-
 {
 public:
    Licq(int argc, char **argv);
@@ -27,9 +26,9 @@ protected:
    bool installBaseDir(void);
    bool quitNowVal;
    ICQ *icq;
-   LicqGUI *licqgui;
+   CMainWindow *licqgui;
 #ifdef USE_KDE
-   Kicq *kicq;
+   KLicq *klicq;
 #endif
 
 };
