@@ -23,5 +23,6 @@ int main(int argc, char **argv)
 #endif
 
    Licq licq(argc, argv);
-   if (!licq.quitNow()) return licq.exec(); 
+   if (!licq.quitNow()) 
+      return licq.exec(); 
 }
