@@ -1,6 +1,10 @@
 #ifndef MSGBOXLIST_H
 #define MSGBOXLIST_H
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <qlistview.h>
 #include <qpopmenu.h>
 
@@ -11,10 +15,11 @@
 class MsgViewItem : public QListViewItem
 {
 public:
-   MsgViewItem (Message *, unsigned short, QListView *);
+   MsgViewItem (CUserEvent *, unsigned short, QListView *);
+   ~MsgViewItem(void);
    virtual const char *key (int column, bool ascending) const;
    short index;
-   Message msg;
+   CUserEvent *msg;
 
 protected:
    virtual void paintCell ( QPainter *, const QColorGroup &, int column, int width, int align);
@@ -28,7 +33,7 @@ class MsgView : public QListView
 {
 public:
    MsgView (QWidget *parent = 0, const char *name = 0);
-   Message *currentMsg(void);
+   CUserEvent *currentMsg(void);
    void markRead(short);
 protected:
    void mouseReleaseEvent(QMouseEvent *e); 
