@@ -1,6 +1,9 @@
 #ifndef OUTPUTWIN_H
 #define OUTPUTWIN_H
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <qwidget.h>
 #include <qmlined.h>
@@ -10,26 +13,19 @@
 #include <stdio.h>
 #include <stdarg.h>
 
+#include "log.h"
 #include "mledit.h"
 
 //=====OutputWin===================================================================================
-class OutputWin : public QWidget
+class OutputWin : public QWidget, public COutputWindow
 {
 public:
    OutputWin (QWidget *parent = 0, const char *name = 0);
-   ~OutputWin (void) {};
-   void wprintf(char *formatIn, ...);
+   virtual void wprintf(const char *formatIn, va_list argp);
 protected:
-   void resizeEvent (QResizeEvent *);
-   void operator<<(const char *d);
-   void operator<<(char d);
-   void operator<<(unsigned long d);
-   void operator<<(unsigned short d);
-   
+   void resizeEvent (QResizeEvent *);   
    MLEditWrap *outputBox;
    QPushButton *btnHide, *btnClear;
-   QCheckBox *chkDebug;
-   QFile *debugFile;
 };
 
 
