@@ -1,6 +1,10 @@
 #ifndef packet_h
 #define packet_h
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 const int MAX_PACKET_SIZE = 4096;
 
 class Packet
