@@ -1,6 +1,10 @@
 #ifndef REMOTESERVER_H
 #define REMOTESERVER_H
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <vector.h>
 #include "icq-defines.h"
 
