@@ -1,3 +1,7 @@
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "requestdlg.h"
 
 RequestDlg::RequestDlg(QWidget *parent = NULL, char *name = NULL) : QDialog(parent, name, true)
