@@ -1,6 +1,10 @@
 #ifndef REQUESTDLG_H
 #define REQUESTDLG_H
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <qpushbutton.h>
 #include <qradiobutton.h>
 #include <qdialog.h>
