@@ -4,6 +4,10 @@
 // Search user code base written by Alan Penner (apenner@andrew.cmu.edu)
 // modified by Graham Roff
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <qdialog.h>
 #include <qpushbt.h>
 #include <qlabel.h>
@@ -28,7 +32,7 @@ public:
 class SearchItem : public QListViewItem
 {
 public:
-   SearchItem(struct UserStatusline &, QListView *parent);  
+   SearchItem(struct UserBasicInfo &, QListView *parent);  
    unsigned long uin();
 protected:
    unsigned long uinVal;
@@ -50,16 +54,18 @@ protected:
    QGroupBox *OtherBox;
 
    unsigned long searchSequence;
-   QPushButton *btnCancelSearch, *btnAdd;
+   QPushButton *btnDone, *btnAdd, *btnSearchAgain;
    SearchUserView *foundView;
    QLabel *lblSearch;
   
 
 public slots:
    virtual void show();
+   virtual void hide();
    void startSearch();
    void addUser();
-   void userFound(struct UserStatusline &, unsigned long);
+   void userFound(struct UserBasicInfo &, unsigned long);
+   void resetSearch();
    void doneSearch(unsigned short, char);   
 };
 
